# Generated by roxygen2: do not edit by hand

export(cds_accept_licence)
export(cds_accepted_licences)
export(cds_account_metrics)
export(cds_assign_star)
export(cds_build_request)
export(cds_catalogue_vocabulary)
export(cds_check_authentication)
export(cds_cite_dataset)
export(cds_dataset_form)
export(cds_delete_job)
export(cds_download_jobs)
export(cds_estimate_costs)
export(cds_get_account)
export(cds_get_token)
export(cds_job_results)
export(cds_list_datasets)
export(cds_list_jobs)
export(cds_list_licences)
export(cds_python_to_r)
export(cds_remove_star)
export(cds_search_datasets)
export(cds_set_token)
export(cds_starred)
export(cds_submit_job)
export(cds_token_works)
importFrom(rlang,.data)
importFrom(rlang,.env)
